==> haskell-roman-numerals-0.5.1.5-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-roman-numerals/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: roman-numerals
version: 0.5.1.5
id: roman-numerals-0.5.1.5-e3bdc5830c32bed2d93467972766bc3b
key: roman_B7QVlTz1tLF546ROET6tvX
license: BSD3
copyright: 2009–2014 Roel van Dijk
maintainer: Roel van Dijk <vandijk.roel@gmail.com>
stability: stable
homepage: https://github.com/roelvandijk/roman-numerals
synopsis: Parsing and pretty printing of Roman numerals
description:
    This library provides functions for parsing and pretty printing
    Roman numerals. Because the notation of Roman numerals has varied
    through the centuries this package allows for some customisation
    using a configuration that is passed to the conversion functions.
category: Numerical, Parsing
author: Roel van Dijk <vandijk.roel@gmail.com>
exposed: True
exposed-modules:
    Text.Numeral.Roman
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/roman-numerals-0.5.1.5
library-dirs: /usr/lib/ghc-7.10.3/site-local/roman-numerals-0.5.1.5
data-dir: /usr/share/arm-linux-ghc-7.10.3/roman-numerals-0.5.1.5
hs-libraries: HSroman-numerals-0.5.1.5-B7QVlTz1tLF546ROET6tvX
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base-unicode-symbols-0.2.2.4-e7aa55c215dabb9b310d3d116ecccda3
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
haddock-interfaces: /usr/share/doc/haskell-roman-numerals/html/roman-numerals.haddock
haddock-html: /usr/share/doc/haskell-roman-numerals/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-roman-numerals-0.5.1.5-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-roman-numerals/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: roman-numerals
version: 0.5.1.5
id: roman-numerals-0.5.1.5-895a0ef14eb8678de90c7da056b82bde
key: roman_JyvfOuBzk3pEZgDeK7YPAM
license: BSD3
copyright: 2009–2014 Roel van Dijk
maintainer: Roel van Dijk <vandijk.roel@gmail.com>
stability: stable
homepage: https://github.com/roelvandijk/roman-numerals
synopsis: Parsing and pretty printing of Roman numerals
description:
    This library provides functions for parsing and pretty printing
    Roman numerals. Because the notation of Roman numerals has varied
    through the centuries this package allows for some customisation
    using a configuration that is passed to the conversion functions.
category: Numerical, Parsing
author: Roel van Dijk <vandijk.roel@gmail.com>
exposed: True
exposed-modules:
    Text.Numeral.Roman
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/roman-numerals-0.5.1.5
library-dirs: /usr/lib/ghc-7.10.3/site-local/roman-numerals-0.5.1.5
data-dir: /usr/share/arm-linux-ghc-7.10.3/roman-numerals-0.5.1.5
hs-libraries: HSroman-numerals-0.5.1.5-JyvfOuBzk3pEZgDeK7YPAM
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base-unicode-symbols-0.2.2.4-e7aa55c215dabb9b310d3d116ecccda3
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
haddock-interfaces: /usr/share/doc/haskell-roman-numerals/html/roman-numerals.haddock
haddock-html: /usr/share/doc/haskell-roman-numerals/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
